<?php
namespace PME\Modules\Planejamento\Prato;

use Zeedhi\Framework\DTO;

class EmissaoReceitasController extends \Zeedhi\Framework\Controller\Report {
    protected $reportService;
    protected $birtStrategy;
    protected $utilities;
    protected $Lista;
    protected $crudService;
    protected $connection;
    protected $environment;
    protected $newCode;
    
    const TABLE_LISTA = "LISTA";

    public function __construct($reportService, $birtStrategy, $utilities, $Lista, $crudService, $connection, $environment, $newCode) {
        $this->birtStrategy  = $birtStrategy;
        $this->utilities     = $utilities;
        $this->Lista         = $Lista;
        $this->crudService    = $crudService;
        $this->connection = $connection;
        $this->environment   = $environment;
        $this->newCode = $newCode;

        parent::__construct($reportService);
    }
    
    protected $reportMapping = array (
        'PLA01300' => array (
            'strategy' => 'BIRT',
            'parameterMapping' => array (
                "CDFILIAL"     => "P_CDFILIAL",
                "PRATOINI"     => "P_CDPRATOINICIO",
                "PRATOFIM"     => "P_CDPRATOFINAL",
                "NIVEL"        => "P_NIVEL",
                "MAXNIVEL"     => "P_MAXNIVEL",
                "CDFILIPROC"   => "P_CDFILIPROC",
                "NRORG"        => "P_NRORG",
                "CDFILCENTPME" => "P_CDFILCENTPME"
            )
        ),
        'pla01305' => array (
            'strategy' => 'BIRT',
            'parameterMapping' => array (
                "LISTAFILI"  =>  "P_LISTAFILI",
                "PRATOINI"   =>  "P_CDPRATOINIC",
                "PRATOFIM"   =>  "P_CDPRATOFINA",
                "DTINI"      =>  "P_DTINICIAL",
                "DTFIN"      =>  "P_DTFINAL",
                "PRATOINI"   =>  "P_PRATOINICIAL",
                "PRATOFIM"   =>  "P_PRATOFINAL"
            )
        ),
        'pla01306' => array (
            'strategy' => 'BIRT',
            'parameterMapping'   => array (
                "CDFILIAL"     => "P_CDFILIAL",
                "PRATOINI"     => "P_CDPRATOINIC",
                "PRATOFIM"     => "P_CDPRATOFINA",
                "CDPICTPRAT"   => "P_CDPICTPRAT",
                "NRORG"        => "P_NRORG",
                "CDFILCENTPME" => "P_CDFILCENTPME"
            )
        ),
        'pla05500' => array (
            'strategy' => 'BIRT',
            'parameterMapping' => array (
                "IDTIPORECE"  => "P_IDTIPORECE",
                "CDFILIALAUX" => "P_CDFILIAL",
                "CDFILCENTPME"=> "P_CDFILCENTPME",
                "CDTIPOCARD"  => "P_CDTIPOCARD",
                "PRODINICIAL" => "P_PRODUTOINI",
                "PRODFINAL"   => "P_PRODUTOFIN",
                "CDPICTPROD"  => "P_CDPICTPROD",
                "CDPICTPRAT"  => "P_CDPICTPRAT",
                "LISTASERV"   => "P_LISTASERV",
                "LISTAFILI"   => "P_LISTAFILI",
                "NRORG"       => "P_NRORG"
            )
        ),
        'pla05000' => array (
            'strategy' => 'BIRT',
            'parameterMapping'   => array (
                "IDTIPORECE"   => "P_IDTIPORECE",
                "CDFILIAL"     => "P_CDFILIAL",
                "CDNUTRIENTE"  => "P_CDNUTRIENTE",
                "CDFILIALAUX"  => "P_CDFILAUXPRAT",
                "CDSERVFILI"   => "P_CDSERVFILI",
                "CDFILCENTPME" => "P_CDFILCENTPME",
                "CDTIPOCARD"   => "P_CDTIPOCARD",
                "NIVEL"        => "P_NIVEL",
                "PRATOINI"     => "P_CDPRATOINIC",
                "PRATOFIM"     => "P_CDPRATOFINA",
                "ORDENA"       => "P_ORDENA",
                "CDPICTPRAT"   => "P_CDPICTPRAT",
                "NRORG"        => "P_NRORG"
            )
        ),
        'pla05400' => array (
            'strategy' => 'BIRT',
            'parameterMapping'   => array (
                "GRUPFILI"     => "P_CDGRUPO",
                "CDFILIAL"     => "P_CDFILIAL",
                "CDFILIALAUX"  => "P_CDFILAUXPRAT",
                "PRATOINI"     => "P_CDPRATINI",
                "PRATOFIM"     => "P_CDPRATFIN",
                "PRODINICIAL"  => "P_CDPRODINI",
                "PRODFINAL"    => "P_CDPRODFIN",
                "IDTPREQPRODFILI" => "P_IDTPREQPRODFILI",
                "CDPICTPRAT"   => "P_CDPICTPRAT",
                "CDPICTPROD"   => "P_CDPICTPROD",
                "CDFILCENTPME"   => "P_CDFILCENTPME",
                "NRORG"        => "P_NRORG"
            )
        ),
        'pla013B' => array (
            'strategy' => 'BIRT',
            'parameterMapping'   => array (
                "CDTIPOCARD"  => "P_CDTIPOCARD",
                "IDTIPORECE"   => "P_IDTIPORECE",
                "CDFILIAL"     => "P_CDFILIAL",
                "CDSERVFILI"   => "P_CDSERVFILI",
                "PRATOINI"     => "P_CDPRATOINIC",
                "PRATOFIM"     => "P_CDPRATOFINA",
                "CDPICTPRAT"   => "P_CDPICTPRAT",
                "CDPICTPROD"   => "P_CDPICTPROD",
                "NRORG"        => "P_NRORG",
                "CDNUTRIENTE"  => "P_CDNUTRIENTE",
                "CDFILCENTPME" => "P_CDFILCENTPME"
            )
        ),
    );
    
    public function beforeProcessReport(DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();
        $nrorg = $this->utilities->getNrOrg();
        $row['NRORG'] = $nrorg;
        
        $row['LISTAFILI'] = '';
        $row['LISTASERV'] = '';
        $row['CDTIPOCARD'] = '';
        
        if($row['ORDENA'] == 0) $row['NIVEL'] = 10;
        else $row['NIVEL'] = isset($row['NIVEL']) ? $row['NIVEL'] * 2 : 0;

        $row['PRATOINI'] = ($row['PRATOINI']) ? $row['PRATOINI'] : '0';
        // $row['PRATOFIM'] = $row['PRATOFIM'] . "Z";    
        $row['PRATOFIM'] = str_pad($row['PRATOFIM'], 10, "z", STR_PAD_RIGHT); 
        $row['PRODINICIAL'] = ($row['PRODINI']) ? $row['PRODINI'] : '0';
        $row['PRODFINAL'] = $row['PRODFIN'] . "Z";
        
        $tpCard = '';
        
        if($row['CD_REPORT_CODE'] === 'pla05500'){
            if($row['IDTIPORECE'] !== 'P' && $row['IDTIPORECE'] !== 'T'){
                $cdFiliServ = $this->getFiliServ($row);
                $this->nrlista = $this->insertLista($cdFiliServ);
                $row["NRLISTA"] = $this->nrlista;
            }
            if($row['IDTIPORECE'] === 'F'){
                $row['LISTAFILI'] = $this->nrlista;
                $row['LISTASERV'] = NULL;
            } else if($row['IDTIPORECE'] == 'S'){
                $row['LISTAFILI'] = NULL;
                $row['LISTASERV'] = $this->nrlista;
            } else if($row['IDTIPORECE'] == 'P'){
                $unidade = $row['CDFILIAL2'];
                $row['CDFILIALAUX'] = $unidade;

                $row['LISTAFILI'] = NULL;
                $row['LISTASERV'] = NULL;
            } else if ($row["IDTIPORECE"] === 'T') {
                $row['LISTAFILI'] = NULL;
                $row['LISTASERV'] = NULL;
                if (empty($row['CDTIPOCARD1']) === false) $tpCard = join("_", $row['CDTIPOCARD1']);
                else {
                    $row['CDTIPOCARD'] = $row['CDTIPOCARD1'];
                    $tpCards = $this->getTpcardEmissaoReceitas($row);           
                    $tpCard = '';               
                    foreach ($tpCards as $tpc) {
                      if (strpos($tpCard, $tpc['CDTIPOCARD']) === false) {
                        $tpCard .= $tpc['CDTIPOCARD'] . "_";
                      }
                    }
                }
                
                $row['CDTIPOCARD'] = $this->Lista->geraLista($tpCard, $nrorg);
            }
        }
        
        if ($row['CD_REPORT_CODE'] === 'pla05000') {
            if ($row['CDSERVFILI1'] === null || $row['CDSERVFILI2'] === null) {
                $row['CDSERVFILI'] = 'X';
            }
            if (count($row['CDNUTRIENTE']) > 0) {
               $row['CDNUTRIENTE'] = join("_", $row['CDNUTRIENTE']);
            } else {
               $row['CDNUTRIENTE'] = 'T';
            }
            
            if ($row['PROJECT'] === 'PAE' AND $row['IDTIPORECE'] === 'T') { 
              $row['CDTIPOCARD'] = $row['CDTIPOCARD2'];
            }
        }
        
        if ($row['CD_REPORT_CODE'] === 'pla05400') {
            if (!($row['GRUPFILI'])) {
                $row['GRUPFILI'] = 'T';
            }
            
            if (count($row['CDFILIAL']) > 0) {
                $unidade = join("_", $row['CDFILIAL']);
            } else {
                $unidade = 'T';
            }
            $row['CDFILIAL'] = $unidade;
            
            $rowsReq = $row['IDTPREQPRODFILI'];
            $tipoReqProd = 'EDP';    
            if (!(in_array('E', $rowsReq))) $tipoReqProd = substr_replace($tipoReqProd, 'X', 0, 1);
            if (!(in_array('D', $rowsReq))) $tipoReqProd = substr_replace($tipoReqProd, 'X', 1, 1);
            if (!(in_array('P', $rowsReq))) $tipoReqProd = substr_replace($tipoReqProd, 'X', 2, 1);
            $row['IDTPREQPRODFILI'] = $tipoReqProd;
        }
        
        if ($row['CD_REPORT_CODE'] === 'pla013B') {
            if (count($row['CDNUTRIENTE']) > 0) $row['CDNUTRIENTE'] = join("_", $row['CDNUTRIENTE']);
            else $row['CDNUTRIENTE'] = 'T';
            
            $row['CDTIPOCARD'] = $row['CDTIPOCARD2'];
        }
        $this->birtStrategy->setReportLocale($this->utilities->getLanguage());
        $this->birtStrategy->setReportFormat(strtolower($row['reportFormat']));   
    }
    
    private function insertLista($cdlistaArray) {
        $dataSourceName = strtolower(self::TABLE_LISTA);
        $nrlista = $this->newCode->getCodeByTableName(self::TABLE_LISTA, $this->environment->getNrOrg());
        $sql = "INSERT INTO " . self::TABLE_LISTA . " (NRLISTA, CDLISTA) VALUES (:NRLISTA, :CDLISTA)";
        
        foreach ($cdlistaArray as $cdlista) {
            $params = array(
                "NRLISTA" => $nrlista,
                "CDLISTA" => $cdlista
            );
            $query = $this->connection->prepare($sql);
    	    $query->execute($params);
        }
        
        return $nrlista;
    }
    
    private function returnFilial($params){
        $sqlFilial = "SELECT DISTINCT F.CDFILIAL AS CDFILIAL FROM FILIAL F INNER JOIN FILIOPER FO ON FO.NRORG = F.NRORG AND FO.CDFILIAL = F.CDFILIAL LEFT JOIN FILGRUPFILI FG ON F.NRORG = FG.NRORG AND F.CDFILIAL = FG.CDFILIAL WHERE F.NRORG = :NRORG AND FO.CDOPERADOR = :CDOPERADOR AND ( :CDGRUPFILI = FG.CDGRUPFILI OR :CDGRUPFILI = 'T' ) ORDER BY CDFILIAL";
        
        try{
            $std = $this->connection->prepare($sqlFilial);
            $std->execute($params);
            $cdFiliServ = $std->fetchAll();
            $cdFiliServ = (array_column($cdFiliServ, 'CDFILIAL'));
            return $cdFiliServ;
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
    private function returnFiliServ($params){
        $sqlFiliServ = "SELECT DISTINCT (F.CDFILIAL || S.CDSERVFILI) AS CDFILISERV FROM FILIAL F INNER JOIN FILIOPER FO ON FO.NRORG = F.NRORG AND FO.CDFILIAL = F.CDFILIAL LEFT JOIN FILGRUPFILI FG ON F.NRORG = FG.NRORG AND F.CDFILIAL = FG.CDFILIAL RIGHT JOIN SERVICO S ON F.CDFILIAL = S.CDFILIAL WHERE F.NRORG = :NRORG AND F.IDCNTRRESC = 'N' AND FO.CDOPERADOR = :CDOPERADOR AND ( :CDGRUPFILI = FG.CDGRUPFILI OR :CDGRUPFILI = 'T' ) AND VALOR_NA_LISTA(F.CDFILIAL, :CDFILIAL) <> 0 ORDER BY 1";
        
        try{
            $std = $this->connection->prepare($sqlFiliServ);
            $std->execute($params);
            $cdFiliServ = $std->fetchAll();
            $cdFiliServ = (array_column($cdFiliServ, 'CDFILISERV'));
            return $cdFiliServ;
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
    private function getFiliServ($row){
        if (empty($row['CDFILIAL1']) === true) $row['TODOSUNIDADES'] = 'S';
        else $row['TODOSUNIDADES'] = 'N';
        if (empty($row['CDSERVFILI1']) === true) $row['TODOSSERVICOS'] = 'S';
        else $row['TODOSSERVICOS'] = 'N';
        $cdgrupfili = isset($row['GRUPFILI']) && $row['GRUPFILI'] ? $row['GRUPFILI'] : 'T';
        
        if($row['IDTIPORECE'] === 'F'){
            if($row['TODOSUNIDADES'] === 'S'){
                $params = array(
                    'CDOPERADOR' =>  $this->environment->getCdOperador(),
                    'NRORG'      =>  $this->environment->getNrOrg(),
                    'CDGRUPFILI' =>  $cdgrupfili
                );
                
                $filiais = $this->returnFilial($params); 
                return $filiais;
            } else{
                $filiais = $row['CDFILIAL1'];
                return $filiais;
            }
        } else if($row["IDTIPORECE"] === 'S'){
            if($row['TODOSUNIDADES'] === 'S'){
                if($row['TODOSSERVICOS'] === 'S'){
                    $params = array(
                        'CDOPERADOR' => $this->environment->getCdOperador(),
                        'NRORG' => $this->environment->getNrOrg(),
                        'CDGRUPFILI' => $cdgrupfili,
                        'CDFILIAL' => 'T'
                    );
                    $cdFiliServ = $this->returnFiliServ($params); 
                    return $cdFiliServ;
                } else{
                    $servicos = $row['CDSERVFILI1'];
                    $cdFiliServ = array();
                    foreach($servicos as $servico){
                        $cdFiliServ[] = $servico['CDFILIAL'].$servico['CDSERVFILI'];
                    }
                    return $cdFiliServ;
                }
            } else{
                if($row['TODOSSERVICOS'] === 'S'){
                    $rowFilial = implode("_", $row['CDFILIAL1']);
                    $params = array(
                        'CDOPERADOR' => $this->environment->getCdOperador(),
                        'NRORG' => $this->environment->getNrOrg(),
                        'CDGRUPFILI' => $cdgrupfili,
                        'CDFILIAL' => $rowFilial
                    );
                    $cdFiliServ = $this->returnFiliServ($params);
                    return $cdFiliServ;
                } else{
                    $servicos = $row['CDSERVFILI1'];
                    $cdFiliServ = array();
                    foreach($servicos as $servico){
                        $cdFiliServ[] = $servico;
                    }
                    return $cdFiliServ;
                }
            }
        }
    }
    
    private function getUnidadesEmissaoReceitas($rows) {
        $dataSourceName = 'unidadeIdcntrresc';
        
        $conditions = array(
             array(
                 'columnName' => 'CDGRUPFILI',
                 'operator' => '=',
                 'value' => $rows['GRUPFILI'] ? $rows['GRUPFILI'] : 'T'
             )
        );
                
        $result = $this->crudService->getFilteredDataSet($dataSourceName, $conditions)->getRows();
        return $result;
    }
    
    private function getTpcardEmissaoReceitas($rows){
        $nrorg = $this->utilities->getNrOrg();
        $dataSourceName = 'tpCardapioPorCentralAtivo';
        
        $conditions = array(       
            array(
                'columnName' => 'IDTPCARDATIV',
                'operator' => '=',
                'value' => 'S'
            ),
            array(
                'columnName' => 'CDFILCENTPME',
                'operator' => '=',
                'value' =>  $rows['CDFILCENTPME']
            ),
            array(
                'columnName' => 'NRPASTATCARD',
                'operator' => '=',
                'value' => null
            ),
            array(
                'columnName' => 'NRORG',
                'operator' => '=',
                'value' => $nrorg
            )
        );
        
        $result = $this->crudService->getFilteredDataSet($dataSourceName, $conditions)->getRows();
        return $result;
    }
}