/* TEKNISA

Nome: 7601_PMESTPO_CONSUMO_PLANEJADO_PME.SQL

Descrio:
Clculo do Consumo Planejado (Cardpio, Consumo por Servio Fixo ou
Percapita) e gravao na tabela CONSPLAN ou PREVRETI.

P_CDFILCENTPME - Codigo da Central de Merenda
P_CDFILIAL     - Codigo da Filial
P_CDTIPOCARD   - Codigo do Tipo de Cardapio
P_CDSERVFILI   - String contendo sequencia de Servios a serem calculados
P_DTINICIAL    - Data inicial
P_DTFINAL      - Data final
P_IDARQUIVO    - Identificador da tabela a ser gravada
                 "P" -> PREVRETI
                 "C" -> CONSPLAN
                 "A" -> AMBAS
P_IDPRODUTOS   - Identificador dos produtos a serem gravados.
                 Formato "XXX"
                 1 posio = "C" -> Cardpio
                 2 posio = "F" -> Consumo por Servio Fixo
                 3 posio = "P" -> Consumo por Servio Percapita
P_IDSEPPRATO   - Identificador de requisio analtica, ou seja, separada
                 por prato ou por setor, consumo fixo e consumo percapita.
                 Formato "S" (setor), "P" (prato) ou "N" (n/a).
P_PEACRESCIMO  - Percentual de acrscimo
P_IDARREDOND   - Identificador de utilizao do arredondamento
                 para requisio do Produto. Formato
                    S - ARREDONDAMENTO DE REQUISIO
                    N - NAO ARREDONDAR
                    C - ARREDONDAMENTO DE COMPRAS

P_NRCONSPLAN   - Nmero sequencial a ser utilizado para gravao dos dados
P_CDPRODUTOINI - Cdigo do Produto inicial
P_CDPRODUTOFIN - Cdigo do Produto final
P_CDOPERADOR   - Cdigo do Operador
P_STDTINICIAL  - Lista de data inicial em string por servio
P_STDTFINAL    - Lista de data final em string por servio

Observao: o formato das strings de data inicial e de data final deve ser
"_YYYYMMDD_YYYYMMDD_YYYYMMDD_"
"_YYYYMMDD_YYYYMMDD_YYYYMMDD_"


Criao:
09/02/2006 - Rafael Christopher de Souza e Silva

*/

IF EXISTS (SELECT * FROM SYSOBJECTS O, SYSUSERS U
                    WHERE
	        O.NAME = 'CONSUMO_PLANEJADO_PME'  AND
	        TYPE = 'P'                        AND
	        U.UID = O.UID                     AND
	        U.NAME = USER
          )
  DROP PROCEDURE CONSUMO_PLANEJADO_PME
  GO

CREATE PROCEDURE CONSUMO_PLANEJADO_PME
   @P_CDFILCENTPME VARCHAR(04),
   @P_CDTIPOCARD   VARCHAR(2000),
   @P_CDFILIAL     VARCHAR(2000),
   @P_CDSERVFILI   VARCHAR(2000),
   @P_DTINICIAL    DATETIME,
   @P_DTFINAL      DATETIME,
   @P_IDARQUIVO    VARCHAR(01),
   @P_IDPRODUTOS   VARCHAR(03),
   @P_IDSEPPRATO   VARCHAR(01),
   @P_PEACRESCIMO  NUMERIC(15,6),
   @P_IDARREDOND   VARCHAR(01),
   @P_NRCONSPLAN   VARCHAR(10),
   @P_CDPRODUTOINI VARCHAR(10),
   @P_CDPRODUTOFIN VARCHAR(10),
   @P_CDOPERADOR   VARCHAR(12)
AS
   DECLARE @V_ARRED           NUMERIC(15, 6);

   DECLARE @V_IDCARDAPIO      VARCHAR(1);
   DECLARE @V_IDCONSFIXO      VARCHAR(1);
   DECLARE @V_IDCONSPERC      VARCHAR(1);

   DECLARE @V_CDFAPRATCPLA    VARCHAR(4);
   DECLARE @V_CDPRATCONSPL    VARCHAR(10);
   DECLARE @V_CDSETOCONSPL    VARCHAR(2);
   DECLARE @V_CDTPPRATCPLA    VARCHAR(2);

   DECLARE @V_IDUTILFATCOR    VARCHAR(1);
   DECLARE @V_IDUTILFATCOC    VARCHAR(1);
   DECLARE @V_IDTIPCALCFAT    VARCHAR(1);

   DECLARE @V_QTDEAUX         NUMERIC(15,6);

   DECLARE @V_QTPRATO         NUMERIC(15,6);

   DECLARE @V_QTPREV          NUMERIC(15,6);
   DECLARE @V_QTPREV1         NUMERIC(15,6);
   DECLARE @V_QTPREV2         NUMERIC(15,6);
   DECLARE @V_QTPREV3         NUMERIC(15,6);
   DECLARE @V_QTPREV4         NUMERIC(15,6);

   DECLARE @V_CDTPRCONSFIX VARCHAR(2);
   DECLARE @V_CDFILCONSFIX VARCHAR(4);
   DECLARE @V_CDPRACONSFIX VARCHAR(10);
   DECLARE @V_CDTPRCONSPER VARCHAR(2);
   DECLARE @V_CDFILCONSPER VARCHAR(4);
   DECLARE @V_CDPRACONSPER VARCHAR(10);

   DECLARE @V_DTLIMITE        DATETIME;
   DECLARE @V_HRLIMITE        VARCHAR(4);
   DECLARE @V_QTCONSPLAN      NUMERIC(15,5);

   DECLARE @V_CDTCACONSPER    VARCHAR(10);
   DECLARE @V_IDCONS          VARCHAR(1);
   DECLARE @V_CDTCACONSFIX    VARCHAR(10);
   DECLARE @V_FERIADO         VARCHAR(1);
   DECLARE @V_QTCOMESTICAR    FLOAT;
   DECLARE @V_TPCARDCONSFIX   VARCHAR(10);
   DECLARE @V_IDPRODNAREQPREV   VARCHAR(1);
   DECLARE @V_PERCACRES       NUMERIC(15,6);

   /* ---------- VARIVEIS QUE CONTERO OS CURSORES E OS REGISTROS --------------- */

   DECLARE @V_REC_CDFILCENTPME VARCHAR(4);
   DECLARE @V_REC_NRCARDPME    VARCHAR(10);
   DECLARE @V_REC_NRCARDIAPME  VARCHAR(10);
   DECLARE @V_REC_CDSERVFILI   VARCHAR(5);
   DECLARE @V_REC_CDFILIAL     VARCHAR(4);
   DECLARE @V_REC_DTCARDIAPME  DATETIME;
   DECLARE @V_REC_QTCOMESTCPME NUMERIC(10,3);
   DECLARE @V_REC_IDCARDESPEC  VARCHAR(1);
   DECLARE @V_REC_CDTIPOCARD   VARCHAR(10);
   DECLARE @V_REC_CDPRATO      VARCHAR(10);
   DECLARE @V_REC_CDFILAUXPRAT VARCHAR(4);
   DECLARE @V_REC_VRPECONSCPME FLOAT;
   DECLARE @V_REC_CDPRODUTO      VARCHAR(10);
   DECLARE @V_REC_QTPRODUTO      NUMERIC(15,6);
   DECLARE @V_REC_SGUNIDADE      VARCHAR(5);
   DECLARE @V_REC_VRPEFATCOC     FLOAT;
   DECLARE @V_REC_VRPEFATCOR     FLOAT;
   DECLARE @V_REC_HRTEMPPREP     VARCHAR(5);
   DECLARE @V_REC_CDAPRERECE     VARCHAR(3);

   DECLARE @V_REC_ARR_NRCONSPLAN   VARCHAR(10);
   DECLARE @V_REC_ARR_CDFILICPLA   VARCHAR(4);
   DECLARE @V_REC_ARR_CDSERVCPLA   VARCHAR(5);
   DECLARE @V_REC_ARR_DTCONSPLAN   DATETIME;
   DECLARE @V_REC_ARR_IDCONSPLAN   VARCHAR(01);
   DECLARE @V_REC_ARR_CDFAPRATCPLA VARCHAR(4);
   DECLARE @V_REC_ARR_CDPRATCONSPL VARCHAR(10);
   DECLARE @V_REC_ARR_CDPRODCPLA   VARCHAR(10);
   DECLARE @V_REC_ARR_DTLIMITECPLA DATETIME;
   DECLARE @V_REC_ARR_HRLIMITECPLA VARCHAR(05);
   DECLARE @V_REC_ARR_CDTPPRATCPLA VARCHAR(2);
   DECLARE @V_REC_ARR_CDCLIECPLA   VARCHAR(21);
   DECLARE @V_REC_ARR_CDDESTFICPLA VARCHAR(3);
   DECLARE @V_REC_ARR_VRARREDREQ   NUMERIC(10,3);
   DECLARE @V_REC_ARR_VRARREDCMP   NUMERIC(10,3);
   DECLARE @V_REC_ARR_QTCONSPLAN   NUMERIC(15,6);
   DECLARE @V_REC_ARR_QTCONSPLANT1 NUMERIC(15,6);
   DECLARE @V_REC_ARR_QTCONSPLANT2 NUMERIC(15,6);
   DECLARE @V_REC_ARR_QTCONSPLANT3 NUMERIC(15,6);
   DECLARE @V_REC_ARR_QTCONSPLANT4 NUMERIC(15,6);

   DECLARE @V_CONSPLAN_DTDATA       DATETIME;
   DECLARE @V_CONSPLAN_CDSERVFILI   VARCHAR(5);
   DECLARE @V_CONSPLAN_HRINICATEN   VARCHAR(4);
   DECLARE @V_CONSPLAN_NRCARDAPIO   VARCHAR(10);
   DECLARE @V_CONSPLAN_CDCLIENTE    VARCHAR(21);
   DECLARE @V_CONSPLAN_CDDESTFILI   VARCHAR(3);
   DECLARE @V_CONSPLAN_QTCOMESTICAR FLOAT;
   DECLARE @V_CONSPLAN_CDFILIAL     VARCHAR(4);

   DECLARE @V_CONSSERVPME_CDFILCENTPME VARCHAR(4);
   DECLARE @V_CONSSERVPME_CDSERVFILI   VARCHAR(5);
   DECLARE @V_CONSSERVPME_CDFILIAL     VARCHAR(4);
   DECLARE @V_CONSSERVPME_DTCONSERVPME DATETIME;
   DECLARE @V_CONSSERVPME_CDPRODUTO    VARCHAR(10);
   DECLARE @V_CONSSERVPME_QTCONSERVPME FLOAT;
   DECLARE @V_CONSSERVPME_IDQTDECONPME VARCHAR(1);

   /* VARIAVEIS BIND */
   DECLARE @w_8 VARCHAR(1);
   DECLARE @w_9 VARCHAR(1);
   DECLARE @w_F VARCHAR(1);
   DECLARE @w_P VARCHAR(1);
   DECLARE @w_A VARCHAR(1);
   DECLARE @w_ZERO VARCHAR(1);

BEGIN
   SET @w_9 = '8';
   SET @w_9 = '9';
   SET @w_F = 'F';
   SET @w_P = 'P';
   SET @w_A = 'A';
   SET @w_ZERO = 0;

   /* --------------------- IDENTIFICADORES DE CLCULO ---------------------- */
   SET @V_IDCARDAPIO = SUBSTRING(@P_IDPRODUTOS, 1, 1);         /* CARDPIO          */
   SET @V_IDCONSFIXO = SUBSTRING(@P_IDPRODUTOS, 2, 1);         /* CONSUMO FIXO      */
   SET @V_IDCONSPERC = SUBSTRING(@P_IDPRODUTOS, 3, 1);         /* CONSUMO PERCAPITA */

   /* ----------------- CALCULO DOS PRODUTOS DOS CARDAPIOS ------------------ */
   IF (@V_IDCARDAPIO = 'C') BEGIN
      SELECT
         @V_IDUTILFATCOR = MAX(IDUTILFATCOR),
         @V_IDUTILFATCOC = MAX(IDUTILFATCOC),
         @V_IDTIPCALCFAT = MAX(IDTIPCALCFAT)
      FROM
         PARAMPLANEJA
      WHERE
         CDFILIAL = @P_CDFILCENTPME;

      IF @V_IDUTILFATCOC IS NULL BEGIN
         SET @V_IDUTILFATCOC = 'S';
      END;
      IF @V_IDUTILFATCOR IS NULL BEGIN
         SET @V_IDUTILFATCOR = 'S';
      END;
      IF @V_IDTIPCALCFAT IS NULL BEGIN
         SET @V_IDTIPCALCFAT = 'T';
      END;

      DECLARE CUR_CARDAPIO CURSOR FOR
      SELECT
         CD.CDFILCENTPME, CD.NRCARDPME,   CD.NRCARDIAPME,
         CD.CDSERVFILI,   CD.CDFILIAL,    CD.DTCARDIAPME,
         CD.QTCOMESTCPME, CD.IDCARDESPEC, C.CDTIPOCARD
      FROM
         CARDAPIOPME C, CARDIAPME CD, FILIAL F, FILITIPOCARD TC
      WHERE
         (C.CDFILCENTPME = @P_CDFILCENTPME                  ) AND
         (CHARINDEX(C.CDTIPOCARD , ISNULL(@P_CDTIPOCARD, C.CDTIPOCARD )) > 0) AND
         (CHARINDEX(CD.CDFILIAL  , ISNULL(@P_CDFILIAL  , CD.CDFILIAL  )) > 0) AND
         (CHARINDEX(CD.CDSERVFILI, ISNULL(@P_CDSERVFILI, CD.CDSERVFILI)) > 0) AND
         (C.CDFILCENTPME = CD.CDFILCENTPME                  ) AND
         (C.NRCARDPME    = CD.NRCARDPME                     ) AND
         (CD.CDFILIAL    <> CD.CDFILCENTPME                 ) AND
         (CD.DTCARDIAPME BETWEEN @P_DTINICIAL AND @P_DTFINAL) AND
         (F.CDFILIAL      = CD.CDFILIAL                     ) AND
         (F.CDFILCENTPME  = CD.CDFILCENTPME                 ) AND
         (TC.CDFILCENTPME = C.CDFILCENTPME                  ) AND
         (TC.CDTIPOCARD   = C.CDTIPOCARD                    ) AND
         (TC.CDFILIAL     = CD.CDFILIAL                     ) AND
         (TC.IDTCARATFILI = 'S'                             )
      ORDER BY CD.CDFILIAL, CD.CDSERVFILI, CD.DTCARDIAPME;

      OPEN CUR_CARDAPIO;

      FETCH NEXT FROM CUR_CARDAPIO INTO @V_REC_CDFILCENTPME,
                                        @V_REC_NRCARDPME,
                                        @V_REC_NRCARDIAPME,
                                        @V_REC_CDSERVFILI,
                                        @V_REC_CDFILIAL,
                                        @V_REC_DTCARDIAPME,
                                        @V_REC_QTCOMESTCPME,
                                        @V_REC_IDCARDESPEC,
                                        @V_REC_CDTIPOCARD;

      /* ------------------- LOOP PARA CALCULO DOS CARDAPIOS ---------------- */
      WHILE (@@FETCH_STATUS = 0) BEGIN
         IF @V_REC_QTCOMESTCPME <> 0 BEGIN /* NO CALCULA PRATOS PARA COMENSAIS IGUAL A ZERO */
            /* ----------------- LOOP DA COMPOSIO DO CARDAPIO ---------------- */
            DECLARE CUR_COMPCARDPME CURSOR FOR
            SELECT
               CC.CDPRATO,
               CC.CDFILAUXPRAT,
               SUM(CASE WHEN (CD.TIPO = 'P') AND (PP.VRPERACEIT IS NOT NULL) AND (PP.VRPERACEIT <> 0) THEN
                        100 * (1 - (PP.VRPERACEIT/100) * -1)
                     ELSE CC.VRPECONSCPME END) AS VRPECONSCPME
            FROM
               COMPCARDPME CC
               LEFT JOIN PERACEITPRATO PP ON PP.CDFILCENTPME = @V_REC_CDFILCENTPME AND
                                    PP.CDFILIAL = @V_REC_CDFILIAL AND
                                    PP.CDPRATO = CC.CDPRATO AND
                                    PP.CDFILAUXPRAT = CC.CDFILAUXPRAT AND
                                    PP.CDTIPOCARD = @V_REC_CDTIPOCARD,
               CARDIAPME CA,
               (SELECT
                   'P' AS TIPO,
                   CDFILCENTPME,
                   NRCARDPME,
                   NRCARDIAPME,
                   CDSERVFILI,
                   CDFILIAL,
                   DTCARDIAPME
                FROM
                   CARDIAPME P
                WHERE
                   (P.CDFILCENTPME = @V_REC_CDFILCENTPME ) AND
                   (P.NRCARDPME    = @V_REC_NRCARDPME    ) AND
                   (P.CDSERVFILI   = @V_REC_CDSERVFILI   ) AND
                   (P.CDFILIAL     = P.CDFILCENTPME      ) AND
                   (P.DTCARDIAPME  = @V_REC_DTCARDIAPME  ) AND
                   (NOT EXISTS(SELECT
                                  CDFILIAL
                               FROM
                                  CARDIAPME C
                               WHERE
                                  (C.CDFILCENTPME = P.CDFILCENTPME       ) AND
                                  (C.NRCARDPME    = P.NRCARDPME          ) AND
                                  (C.CDSERVFILI   = P.CDSERVFILI         ) AND
                                  (C.CDFILIAL     = @V_REC_CDFILIAL      ) AND
                                  (C.DTCARDIAPME  = P.DTCARDIAPME        ) AND
                                  (C.IDCARDESPEC  = 'S'                  )
                              )
                   )

                UNION ALL

                SELECT
                   'E' AS TIPO,
                   CDFILCENTPME,
                   NRCARDPME,
                   NRCARDIAPME,
                   CDSERVFILI,
                   CDFILIAL,
                   DTCARDIAPME
                FROM
                   CARDIAPME
                WHERE
                   (CDFILCENTPME = @V_REC_CDFILCENTPME ) AND
                   (NRCARDPME    = @V_REC_NRCARDPME    ) AND
                   (CDSERVFILI   = @V_REC_CDSERVFILI   ) AND
                   (CDFILIAL     = @V_REC_CDFILIAL     ) AND
                   (IDCARDESPEC  = 'S'                 ) AND
                   (DTCARDIAPME  = @V_REC_DTCARDIAPME  )
               ) CD
            WHERE
               (CC.CDFILCENTPME = CD.CDFILCENTPME      ) AND
               (CC.NRCARDPME    = CD.NRCARDPME         ) AND
               (CC.NRCARDIAPME  = CD.NRCARDIAPME       ) AND
               (CA.CDFILCENTPME = CD.CDFILCENTPME      ) AND
               (CA.NRCARDPME    = CD.NRCARDPME         ) AND
               (CA.CDSERVFILI   = CD.CDSERVFILI        ) AND
               (CA.DTCARDIAPME  = CD.DTCARDIAPME       ) AND
               (CA.CDFILIAL     = @V_REC_CDFILIAL      )
            GROUP BY
               CC.CDPRATO,
               CC.CDFILAUXPRAT;

            OPEN CUR_COMPCARDPME;
            FETCH NEXT FROM CUR_COMPCARDPME INTO @V_REC_CDPRATO,
                                                 @V_REC_CDFILAUXPRAT,
                                                 @V_REC_VRPECONSCPME;


            WHILE (@@FETCH_STATUS = 0) BEGIN
               IF (@V_REC_VRPECONSCPME <> 0) BEGIN
                  SET @V_QTPRATO = (@V_REC_VRPECONSCPME * @V_REC_QTCOMESTCPME)/ 100 ;

                  /* ---------------- LOOP DA COMPOSIO DOS PRATOS --------------- */

                  DECLARE CUR_PRODPRAT CURSOR FOR
                  SELECT
                     RECESERV.CDPRODUTO,
                     RECESERV.QTBRUTASE AS QTPRODUTO,
                     RECESERV.SGUNIDADE,
                     RECESERV.VRPEFATCOCSE AS VRPEFATCOC,
                     RECESERV.VRPEFATCORSE AS VRPEFATCOR,
                     ISNULL(RECESERV.HRTEMPPREPSE, '00100') AS HRTEMPPREP,
                     RECESERV.CDAPRERECE
                  FROM
                     PRODUTO,
                     RECESERV
                  WHERE
                     (RECESERV.CDFILAUXPRAT = @V_REC_CDFILAUXPRAT) AND
                     (RECESERV.CDPRATO      = @V_REC_CDPRATO     ) AND
                     (RECESERV.CDFILIAL     = @V_REC_CDFILIAL    ) AND
                     (RECESERV.CDSERVFILI   = @V_REC_CDSERVFILI  ) AND
                     (RECESERV.CDPRODUTO    = PRODUTO.CDPRODUTO  ) AND
                     (PRODUTO.CDARVPROD BETWEEN @P_CDPRODUTOINI AND @P_CDPRODUTOFIN)

                  UNION ALL

                  SELECT
                     RECEFILI.CDPRODUTO,
                     RECEFILI.QTBRUTALO AS QTPRODUTO,
                     RECEFILI.SGUNIDADE,
                     RECEFILI.VRPEFATCOCLO AS VRPEFATCOC,
                     RECEFILI.VRPEFATCORLO AS VRPEFATCOR,
                     ISNULL(RECEFILI.HRTEMPPREPLO, '00100') AS HRTEMPPREP,
                     RECEFILI.CDAPRERECE
                  FROM
                     PRODUTO,
                     RECEFILI
                  WHERE
                     (RECEFILI.CDFILAUXPRAT = @V_REC_CDFILAUXPRAT) AND
                     (RECEFILI.CDPRATO      = @V_REC_CDPRATO     ) AND
                     (RECEFILI.CDFILIAL     = @V_REC_CDFILIAL    ) AND
                     (RECEFILI.CDPRODUTO    = PRODUTO.CDPRODUTO  ) AND
                     (PRODUTO.CDARVPROD BETWEEN @P_CDPRODUTOINI AND @P_CDPRODUTOFIN) AND
                     (NOT EXISTS (SELECT
                                     CDPRATO
                                  FROM
                                     RECESERV
                                  WHERE
                                     (CDFILAUXPRAT = @V_REC_CDFILAUXPRAT) AND
                                     (CDPRATO      = @V_REC_CDPRATO     ) AND
                                     (CDFILIAL     = @V_REC_CDFILIAL    ) AND
                                     (CDSERVFILI   = @V_REC_CDSERVFILI  )
                                  )
                     )

                  UNION ALL

                  SELECT
                     RECETPCARD.CDPRODUTO,
                     RECETPCARD.QTBRUTAPRTP AS QTPRODUTO,
                     RECETPCARD.SGUNIDADE,
                     RECETPCARD.VRPEFATCOCPRTP AS VRPEFATCOC,
                     RECETPCARD.VRPEFATCORPRTP AS VRPEFATCOR,
                     ISNULL(RECETPCARD.HRTEMPPREPPRTP, '00100') AS HRTEMPPREP,
                     RECETPCARD.CDAPRERECE
                  FROM
                     PRODUTO,
                     RECETPCARD
                  WHERE
                     (RECETPCARD.CDFILAUXPRAT = @V_REC_CDFILAUXPRAT) AND
                     (RECETPCARD.CDFILCENTPME = @V_REC_CDFILCENTPME) AND
                     (RECETPCARD.CDPRATO      = @V_REC_CDPRATO     ) AND
                     (RECETPCARD.CDTIPOCARD   = @V_REC_CDTIPOCARD  ) AND
                     (RECETPCARD.CDPRODUTO    = PRODUTO.CDPRODUTO  ) AND
                     (PRODUTO.CDARVPROD BETWEEN @P_CDPRODUTOINI AND @P_CDPRODUTOFIN) AND
                     (NOT EXISTS (SELECT
                                     CDPRATO
                                  FROM
                                     RECEFILI
                                  WHERE
                                     (CDFILAUXPRAT = @V_REC_CDFILAUXPRAT) AND
                                     (CDPRATO      = @V_REC_CDPRATO     ) AND
                                     (CDFILIAL     = @V_REC_CDFILIAL    )
                                  )
                     ) AND
                     (NOT EXISTS (SELECT
                                     CDPRATO
                                  FROM
                                     RECESERV
                                  WHERE
                                     (CDFILAUXPRAT = @V_REC_CDFILAUXPRAT) AND
                                     (CDPRATO      = @V_REC_CDPRATO     ) AND
                                     (CDFILIAL     = @V_REC_CDFILIAL    ) AND
                                     (CDSERVFILI   = @V_REC_CDSERVFILI  )
                                 )
                     )

                  UNION ALL

                  SELECT
                     RECEPADR.CDPRODUTO,
                     RECEPADR.QTBRUTAPR AS QTPRODUTO,
                     RECEPADR.SGUNIDADE,
                     RECEPADR.VRPEFATCOCPR AS VRPEFATCOC,
                     RECEPADR.VRPEFATCORPR AS VRPEFATCOR,
                     ISNULL(RECEPADR.HRTEMPPREPPR, '00100') AS HRTEMPPREP,
                     RECEPADR.CDAPRERECE
                  FROM
                     PRODUTO,
                     RECEPADR
                  WHERE
                     (RECEPADR.CDFILAUXPRAT = @V_REC_CDFILAUXPRAT) AND
                     (RECEPADR.CDPRATO      = @V_REC_CDPRATO     ) AND
                     (RECEPADR.CDPRODUTO    = PRODUTO.CDPRODUTO  ) AND
                     (PRODUTO.CDARVPROD BETWEEN @P_CDPRODUTOINI AND @P_CDPRODUTOFIN) AND
                     (NOT EXISTS (SELECT
                                     CDPRATO
                                  FROM
                                     RECEFILI
                                  WHERE
                                     (CDFILAUXPRAT = @V_REC_CDFILAUXPRAT) AND
                                     (CDPRATO      = @V_REC_CDPRATO     ) AND
                                     (CDFILIAL     = @V_REC_CDFILIAL    )
                                  )
                     ) AND
                     (NOT EXISTS (SELECT
                                     CDPRATO
                                  FROM
                                     RECESERV
                                  WHERE
                                     (CDFILAUXPRAT = @V_REC_CDFILAUXPRAT) AND
                                     (CDPRATO      = @V_REC_CDPRATO     ) AND
                                     (CDFILIAL     = @V_REC_CDFILIAL    ) AND
                                     (CDSERVFILI   = @V_REC_CDSERVFILI  )
                                 )
                     ) AND
                      (NOT EXISTS (SELECT CDPRATO
                                    FROM RECETPCARD
                                   WHERE (RECETPCARD.CDFILAUXPRAT = @V_REC_CDFILAUXPRAT) AND
                                         (RECETPCARD.CDFILCENTPME = @V_REC_CDFILCENTPME) AND
                                         (RECETPCARD.CDPRATO      = @V_REC_CDPRATO     ) AND
                                         (RECETPCARD.CDTIPOCARD   = @V_REC_CDTIPOCARD  )));

                  OPEN CUR_PRODPRAT;
                  FETCH NEXT FROM CUR_PRODPRAT INTO @V_REC_CDPRODUTO,
                                                    @V_REC_QTPRODUTO,
                                                    @V_REC_SGUNIDADE,
                                                    @V_REC_VRPEFATCOC,
                                                    @V_REC_VRPEFATCOR,
                                                    @V_REC_HRTEMPPREP,
                                                    @V_REC_CDAPRERECE;

                  WHILE (@@FETCH_STATUS = 0) BEGIN
                     SET @V_REC_QTPRODUTO = @V_REC_QTPRODUTO * @V_QTPRATO;

                     /* ---------------- EVITA DIVISAO POR ZERO ------------------- */
                     SET @V_QTDEAUX = @V_REC_QTCOMESTCPME;

                     IF (@V_QTDEAUX = 0) OR (@V_QTDEAUX IS NULL) BEGIN
                        SET @V_QTDEAUX = 1;
                     END;

                     /* --------------------- GRAVA NA CONSPLAN ------------------- */

                     SET @V_CDFAPRATCPLA = ' ';
                     SET @V_CDPRATCONSPL = '          ';
                     SET @V_CDSETOCONSPL = '  ';
                     SET @V_CDTPPRATCPLA = '  ';
                     
                     IF (@P_IDSEPPRATO = 'P') BEGIN
                        SET @V_CDFAPRATCPLA = @V_REC_CDFILAUXPRAT;
                        SET @V_CDPRATCONSPL = @V_REC_CDPRATO;
                     END ELSE BEGIN
                        SET @V_CDFAPRATCPLA = ' ';
                        SET @V_CDPRATCONSPL = '          ';
                     END;

                     SELECT @V_IDPRODNAREQPREV = IDPRODNAREQPREV
                       FROM PRODFILI
                      WHERE CDFILIAL = @V_REC_CDFILIAL
                        AND CDPRODUTO = @V_REC_CDPRODUTO;
                   
                     IF (@V_IDPRODNAREQPREV = 'S') BEGIN
                        SET @V_PERCACRES = 0;
                     END ELSE BEGIN
                        SET @V_PERCACRES = @P_PEACRESCIMO;
                     END; 

                     SET @V_DTLIMITE     = CONVERT(DATETIME, CONVERT(VARCHAR, @V_REC_DTCARDIAPME, 103), 103);
                     SET @V_HRLIMITE     = CONVERT(VARCHAR, @V_REC_DTCARDIAPME, 114);
                     SET @V_QTCONSPLAN   = (@V_REC_QTPRODUTO) * (1 + (@V_PERCACRES / 100))

                     EXEC ATUALIZA_CONSPLAN_PME
                                            @P_NRCONSPLAN,
                                            @P_CDFILCENTPME,
                                            @V_REC_CDFILIAL,
                                            @V_REC_CDTIPOCARD,
                                            @V_REC_CDSERVFILI,
                                            'C',
                                            @V_CDFAPRATCPLA,
                                            @V_CDPRATCONSPL,
                                            @V_REC_CDAPRERECE,
                                            @V_CDSETOCONSPL,
                                            @V_REC_CDPRODUTO,
                                            @V_DTLIMITE,
                                            @V_HRLIMITE,
                                            @V_CDTPPRATCPLA,
                                            @V_QTCONSPLAN,
                                            @V_REC_VRPECONSCPME,
                                            @V_QTPRATO,
                                            'S',
                                            @V_REC_DTCARDIAPME;

                     FETCH NEXT FROM CUR_PRODPRAT INTO @V_REC_CDPRODUTO,
                                                       @V_REC_QTPRODUTO,
                                                       @V_REC_SGUNIDADE,
                                                       @V_REC_VRPEFATCOC,
                                                       @V_REC_VRPEFATCOR,
                                                       @V_REC_HRTEMPPREP,
                                                       @V_REC_CDAPRERECE;
                  END; /* LOOP DA COMPOSICAO DOS PRATOS */
                  CLOSE CUR_PRODPRAT;
                  DEALLOCATE CUR_PRODPRAT;
               END;

               FETCH NEXT FROM CUR_COMPCARDPME INTO @V_REC_CDPRATO,
                                                    @V_REC_CDFILAUXPRAT,
                                                    @V_REC_VRPECONSCPME;
            END; /* LOOP DA COMPOSIO DO CARDAPIO */

            CLOSE CUR_COMPCARDPME;
            DEALLOCATE CUR_COMPCARDPME;
         END;
         FETCH NEXT FROM CUR_CARDAPIO INTO @V_REC_CDFILCENTPME,
                                           @V_REC_NRCARDPME,
                                           @V_REC_NRCARDIAPME,
                                           @V_REC_CDSERVFILI,
                                           @V_REC_CDFILIAL,
                                           @V_REC_DTCARDIAPME,
                                           @V_REC_QTCOMESTCPME,
                                           @V_REC_IDCARDESPEC,
                                           @V_REC_CDTIPOCARD;
      END; /* LOOP PARA CALCULO DOS CARDAPIOS */
      CLOSE CUR_CARDAPIO;
      DEALLOCATE CUR_CARDAPIO;
   END;

   /* INICIO CONSUMO POR SERVICO */
   IF (@V_IDCONSFIXO = 'F') OR (@V_IDCONSPERC = 'P') BEGIN
      SELECT
         @V_CDTCACONSPER = MAX(CDTCACONSPER),
         @V_CDTCACONSFIX = MAX(CDTCACONSFIX)
      FROM
         PARAMPLANEJA
      WHERE
         (CDFILIAL = @P_CDFILCENTPME);

      IF ((@V_IDCONSPERC = 'P') AND (@V_CDTCACONSPER IS NOT NULL) AND (@V_IDCONSFIXO = 'F') AND (@V_CDTCACONSFIX IS NOT NULL))  BEGIN
          SET @V_IDCONS = 'PF'; /* BUSCAR CONSUMO FIXO E PER CAPITA*/
      END
      ELSE IF (@V_IDCONSPERC = 'P') AND (@V_CDTCACONSPER IS NOT NULL) BEGIN 
         SET @V_IDCONS = 'P';
      END
      ELSE BEGIN
         IF (@V_IDCONSFIXO = 'F') AND (@V_CDTCACONSFIX IS NOT NULL) BEGIN
            SET @V_IDCONS = 'F';
         END;      
      END;

/* OPEN_CONSPLAN */
      IF (@V_IDCONS = 'C') BEGIN
         /* -- Consumo do CARDAPIO -- */
         DECLARE C_CONSPLAN CURSOR FOR
            SELECT
               CA.DTCARDIAPME,
               CA.CDSERVFILI,
               LEFT(SE.HRINICATEN, 4) AS HRINICATEN,
               CA.NRCARDPME,
               'XXX' CDCLIENTE,
               'XXX' CDDESTFILI,
               CA.QTCOMESTCPME,
               SE.CDFILIAL
            FROM
               CARDIAPME CA,
               SERVICO   SE
            WHERE
               (CA.CDFILCENTPME = @P_CDFILCENTPME)                                   AND
               (CHARINDEX(SE.CDFILIAL,   ISNULL(@P_CDFILIAL,   SE.CDFILIAL  )) <> 0) AND
               (CHARINDEX(SE.CDSERVFILI, ISNULL(@P_CDSERVFILI, SE.CDSERVFILI)) <> 0) AND
               (CA.CDFILIAL     = SE.CDFILIAL    )                                   AND
               (CA.CDSERVFILI   = SE.CDSERVFILI  )                                   AND
               (CA.DTCARDIAPME  BETWEEN @P_DTINICIAL AND @P_DTFINAL)                 AND
               NOT EXISTS (SELECT * FROM CARDACLI
                           WHERE CDFILIAL   = CA.CDFILIAL AND
                                 NRCARDAPIO = CA.NRCARDPME)
            UNION
            SELECT
               CA.DTCARDIAPME,
               CA.CDSERVFILI,
               LEFT(SE.HRINICATEN, 4) AS HRINICATEN,
               CA.NRCARDPME,
               CC.CDCLIENTE,
               CC.CDDESTFILI,
               CC.QTCOMESTICLI QTCOMESTICAR,
               SE.CDFILIAL
            FROM
               CARDACLI  CC,
               CARDIAPME CA,
               SERVICO   SE
            WHERE
               (CA.CDFILCENTPME = @P_CDFILCENTPME)                                   AND
               (CHARINDEX(SE.CDFILIAL,   ISNULL(@P_CDFILIAL,   SE.CDFILIAL  )) <> 0) AND
               (CHARINDEX(SE.CDSERVFILI, ISNULL(@P_CDSERVFILI, SE.CDSERVFILI)) <> 0) AND
               (CA.CDFILIAL     = SE.CDFILIAL    )                                   AND
               (CA.CDSERVFILI   = SE.CDSERVFILI  )                                   AND
               (CA.DTCARDIAPME BETWEEN @P_DTINICIAL AND @P_DTFINAL)                  AND
               (CC.CDFILIAL     = CA.CDFILIAL    )                                   AND
               (CC.NRCARDAPIO   = CA.NRCARDPME   )
            ORDER BY 1, 2, 3, 4, 5, 6;
      END /*END*/
      ELSE BEGIN
         IF (@V_IDCONS = 'P') BEGIN
            /* -- Consumo por Servio PER CAPITA - proporcional aos comensais -- */
            DECLARE C_CONSPLAN CURSOR FOR
               SELECT
                  DT.DTDATA,
                  SE.CDSERVFILI,
                  LEFT(SE.HRINICATEN, 4) AS HRINICATEN,
                  'PPPPPPPPPP' NRCARDAPIO,
                  'XXX' CDCLIENTE,
                  'XXX' CDDESTFILI,
                  SUM(CA.QTCOMESTCPME) QTCOMESTICAR,
                  SE.CDFILIAL
               FROM
                  DATA DT,
                  SERVICO SE,
                  CARDIAPME CA,
                  PARAMPLANEJA PA,
                  SERVTIPOCARD ST
               WHERE
                  (CA.CDFILCENTPME = @P_CDFILCENTPME)                                   AND
                  (CHARINDEX(SE.CDFILIAL,   ISNULL(@P_CDFILIAL,   SE.CDFILIAL  )) <> 0) AND
                  (CHARINDEX(SE.CDSERVFILI, ISNULL(@P_CDSERVFILI, SE.CDSERVFILI)) <> 0) AND
                  (CA.CDFILIAL     = SE.CDFILIAL    )                                   AND
                  (CA.CDSERVFILI   = SE.CDSERVFILI  )                                   AND
                  (CA.DTCARDIAPME  BETWEEN @P_DTINICIAL AND @P_DTFINAL)                 AND
                  (DT.DTDATA       = CA.DTCARDIAPME )                                   AND
                  (PA.CDFILIAL     = CA.CDFILCENTPME)                                   AND
                  (ST.CDFILCENTPME = PA.CDFILIAL    )                                   AND
                  (ST.CDTIPOCARD   = PA.CDTCACONSPER)                                   AND
                  (ST.CDSERVFILI   = SE.CDSERVFILI  )                                   AND
                  (NOT EXISTS (SELECT * FROM CARDACLI
                               WHERE CDFILIAL   = CA.CDFILIAL AND
                                     NRCARDAPIO = CA.NRCARDPME))
               GROUP BY
                  DT.DTDATA,
                  SE.CDSERVFILI,
                  LEFT(SE.HRINICATEN, 4),
                  SE.CDFILIAL
               UNION ALL
               SELECT
                  DT.DTDATA,
                  SE.CDSERVFILI,
                  LEFT(SE.HRINICATEN, 4) AS HRINICATEN,
                  'PPPPPPPPPP' NRCARDAPIO,
                  CC.CDCLIENTE,
                  CC.CDDESTFILI,
                  SUM(CC.QTCOMESTICLI) QTCOMESTICAR,
                  SE.CDFILIAL
               FROM
                  CARDACLI CC,
                  DATA DT,
                  SERVICO SE,
                  CARDIAPME CA,
                  PARAMPLANEJA PA,
                  SERVTIPOCARD ST
               WHERE
                  (CA.CDFILCENTPME = @P_CDFILCENTPME )                                  AND
                  (CHARINDEX(SE.CDFILIAL,   ISNULL(@P_CDFILIAL,   SE.CDFILIAL  )) <> 0) AND
                  (CHARINDEX(SE.CDSERVFILI, ISNULL(@P_CDSERVFILI, SE.CDSERVFILI)) <> 0) AND
                  (CA.CDFILIAL     = SE.CDFILIAL    )                                   AND
                  (CA.CDSERVFILI   = SE.CDSERVFILI  )                                   AND
                  (CA.DTCARDIAPME  BETWEEN @P_DTINICIAL AND @P_DTFINAL)                 AND
                  (DT.DTDATA       = CA.DTCARDIAPME )                                   AND
                  (CC.CDFILIAL     = CA.CDFILIAL    )                                   AND
                  (CC.NRCARDAPIO   = CA.NRCARDPME   )                                   AND
                  (PA.CDFILIAL     = CA.CDFILCENTPME)                                   AND
                  (ST.CDFILCENTPME = PA.CDFILIAL    )                                   AND
                  (ST.CDTIPOCARD   = PA.CDTCACONSPER)                                   AND
                  (ST.CDSERVFILI   = SE.CDSERVFILI  )
               GROUP BY
                  DT.DTDATA,
                  SE.CDSERVFILI,
                  LEFT(SE.HRINICATEN, 4),
                  CC.CDCLIENTE,
                  CC.CDDESTFILI,
                  SE.CDFILIAL
               UNION ALL
               SELECT
                  DT.DTDATA,
                  SE.CDSERVFILI,
                  LEFT(SE.HRINICATEN, 4) AS HRINICATEN,
                  NULL NRCARDAPIO,
                  'XXX' CDCLIENTE,
                  'XXX' CDDESTFILI,
                  0 QTCOMESTICAR,
                  SE.CDFILIAL
               FROM
                  DATA DT,
                  SERVICO SE,
                  PARAMPLANEJA PA,
                  SERVTIPOCARD ST
               WHERE
                  (CHARINDEX(SE.CDFILIAL,   ISNULL(@P_CDFILIAL,   SE.CDFILIAL  )) <> 0) AND
                  (CHARINDEX(SE.CDSERVFILI, ISNULL(@P_CDSERVFILI, SE.CDSERVFILI)) <> 0) AND
                  (DT.DTDATA       BETWEEN @P_DTINICIAL AND @P_DTFINAL)                 AND
                  (PA.CDFILIAL     = @P_CDFILCENTPME                )                   AND
                  (ST.CDFILCENTPME = PA.CDFILIAL                    )                   AND
                  (ST.CDTIPOCARD   = PA.CDTCACONSPER                )                   AND
                  (ST.CDSERVFILI   = SE.CDSERVFILI                  )                   AND
                  (NOT EXISTS (SELECT
                                  CA.CDFILIAL
                               FROM
                                  CARDIAPME CA
                               WHERE
                                  (CA.CDFILIAL    = SE.CDFILIAL  ) AND
                                  (CA.CDSERVFILI  = SE.CDSERVFILI) AND
                                  (CA.DTCARDIAPME = DT.DTDATA)))
               ORDER BY 1, 2, 3, 4, 5, 6;
         END
         ELSE IF(@V_IDCONS = 'F') BEGIN
         /* -- Consumo por Servio 'fixo' - no considera os comensais -- */
            DECLARE C_CONSPLAN CURSOR FOR
               SELECT
                  DT.DTDATA,
                  SE.CDSERVFILI,
                  LEFT(SE.HRINICATEN, 4) AS HRINICATEN,
                  NULL NRCARDAPIO,
                  'XXX' CDCLIENTE,
                  'XXX' CDDESTFILI,
                  0 QTCOMESTICAR,
                  SE.CDFILIAL
               FROM
                  DATA DT,
                  SERVICO SE,
                  PARAMPLANEJA PA,
                  SERVTIPOCARD ST
               WHERE
                  (CHARINDEX(SE.CDFILIAL,   ISNULL(@P_CDFILIAL,   SE.CDFILIAL  )) <> 0) AND
                  (CHARINDEX(SE.CDSERVFILI, ISNULL(@P_CDSERVFILI, SE.CDSERVFILI)) <> 0 OR (@P_CDSERVFILI = 'T')) AND
                  (DT.DTDATA       BETWEEN @P_DTINICIAL AND @P_DTFINAL)                 AND
                  (PA.CDFILIAL     = @P_CDFILCENTPME                  )                 AND
                  (ST.CDFILCENTPME = PA.CDFILIAL                      )                 AND
                  (ST.CDTIPOCARD   = PA.CDTCACONSFIX                  )                 AND
                  (ST.CDSERVFILI   = SE.CDSERVFILI                    )
               ORDER BY
                  DTDATA,
                  SE.CDSERVFILI,
                  LEFT(SE.HRINICATEN, 4);
         END
         ELSE BEGIN
          /* --  P_IDTIPOCONS = PF --  */
          /* -- Consumo por Servio PER CAPITA - proporcional aos comensais -- */
          /* -- Consumo por Servio 'fixo' - no considera os comensais -- */
          DECLARE C_CONSPLAN CURSOR FOR
             SELECT DT.DTDATA,
                 S.CDSERVFILI,
                 LEFT(S.HRINICATEN + '0000', 4) AS HRINICATEN,
                 CA.NRCARDPME AS NRCARDAPIO,
                 CA.CDCLIENTE AS CDCLIENTE,
                 CA.CDDESTFILI AS CDDESTFILI,
                 SUM(CA.QTCOMESTCPME) AS QTCOMESTICAR,
                 S.CDFILIAL
           FROM SERVTIPOCARD ST
                INNER JOIN FILITIPOCARD FT ON FT.CDFILCENTPME = ST.CDFILCENTPME AND
                                              FT.CDTIPOCARD = ST.CDTIPOCARD AND
                                              FT.IDTCARATFILI = 'S'
                INNER JOIN SERVICO S ON S.CDSERVFILI = ST.CDSERVFILI AND
                                        S.CDFILIAL = FT.CDFILIAL
                INNER JOIN PARAMPLANEJA PA ON PA.CDFILIAL = ST.CDFILCENTPME AND
                                              (ST.CDTIPOCARD = PA.CDTCACONSPER OR  ST.CDTIPOCARD = PA.CDTCACONSFIX)
                CROSS JOIN DATA DT
                LEFT JOIN 
                (SELECT CA.CDFILCENTPME, CA.NRCARDPME, CA.CDFILIAL, CA.CDSERVFILI, CA.DTCARDIAPME, 
                        ISNULL(CL.CDCLIENTE, 'XXX') AS CDCLIENTE, 
                        ISNULL(CL.CDDESTFILI, 'XXX') AS CDDESTFILI,
                        ISNULL(CL.QTCOMESTICLI, CA.QTCOMESTCPME) AS QTCOMESTCPME       
                   FROM CARDIAPME CA
                        LEFT JOIN CARDACLI CL ON CL.CDFILIAL = CA.CDFILIAL AND
                                                CL.NRCARDAPIO = CA.NRCARDPME
                  WHERE CA.CDFILCENTPME = @P_CDFILCENTPME
                    AND CA.DTCARDIAPME BETWEEN @P_DTINICIAL AND @P_DTFINAL
                    AND (CHARINDEX(CA.CDFILIAL, ISNULL(@P_CDFILIAL, CA.CDFILIAL)) > 0)          
                    AND (CHARINDEX(CA.CDSERVFILI, ISNULL(@P_CDSERVFILI, CA.CDSERVFILI)) <> 0 OR (@P_CDSERVFILI = 'T'))                  
                ) CA ON CA.CDFILIAL = S.CDFILIAL AND
                        CA.CDSERVFILI = S.CDSERVFILI AND
                        CA.DTCARDIAPME = DT.DTDATA
          WHERE (((ST.CDTIPOCARD = PA.CDTCACONSPER) AND (CA.CDFILCENTPME IS NOT NULL)) OR 
                 (ST.CDTIPOCARD = PA.CDTCACONSFIX))                 
            AND (ST.CDFILCENTPME = @P_CDFILCENTPME ) 
            AND (CHARINDEX(S.CDFILIAL, ISNULL(@P_CDFILIAL, S.CDFILIAL)) > 0)          
            AND (CHARINDEX(S.CDSERVFILI, ISNULL(@P_CDSERVFILI, S.CDSERVFILI)) <> 0 OR (@P_CDSERVFILI = 'T'))            
            AND (DT.DTDATA BETWEEN @P_DTINICIAL AND @P_DTFINAL)
          GROUP BY
               DT.DTDATA,
               S.CDSERVFILI,
               LEFT(S.HRINICATEN + '0000', 4),
               S.CDFILIAL,
               CA.NRCARDPME,
               CA.CDCLIENTE,
               CA.CDDESTFILI
          
          ORDER BY 1, 2, 3, 4, 5, 6;


           
          END
      END;

      OPEN C_CONSPLAN;
      FETCH NEXT FROM C_CONSPLAN INTO @V_CONSPLAN_DTDATA,
                                      @V_CONSPLAN_CDSERVFILI,
                                      @V_CONSPLAN_HRINICATEN,
                                      @V_CONSPLAN_NRCARDAPIO,
                                      @V_CONSPLAN_CDCLIENTE,
                                      @V_CONSPLAN_CDDESTFILI,
                                      @V_CONSPLAN_QTCOMESTICAR,
                                      @V_CONSPLAN_CDFILIAL;

      WHILE (@@FETCH_STATUS = 0) BEGIN
         SELECT
            @V_FERIADO = COUNT(*)
         FROM
            FERIFILI
         WHERE
            (CDFILIAL   = @V_CONSPLAN_CDFILIAL) AND
            (DTFERIFILI = @V_CONSPLAN_DTDATA);

         DECLARE CUR_CONSSERVPME CURSOR FOR
            SELECT
               CS.CDFILCENTPME, CS.CDSERVFILI, CS.CDFILIAL,
               CS.DTCONSERVPME, CS.CDPRODUTO,  CS.QTCONSERVPME, CS.IDQTDECONPME
            FROM
               CONSSERVPME CS, PRODUTO, SERVTIPOCARD ST, PARAMPLANEJA PA, FILITIPOCARD TC
            WHERE
               (CS.CDFILCENTPME = @P_CDFILCENTPME       ) AND
               (CS.CDSERVFILI   = @V_CONSPLAN_CDSERVFILI) AND
               (CS.CDFILIAL     = @V_CONSPLAN_CDFILIAL  ) AND
               (CS.DTCONSERVPME = @V_CONSPLAN_DTDATA    ) AND
               (CS.IDTIPOCONPME = @w_9                  ) AND
               (CS.IDQTDECONPME = @w_F                  ) AND
               (CS.CDPRODUTO    = PRODUTO.CDPRODUTO     ) AND
               (CDARVPROD BETWEEN @P_CDPRODUTOINI AND @P_CDPRODUTOFIN) AND
               (ST.CDFILCENTPME = CS.CDFILCENTPME       ) AND
               (ST.CDSERVFILI   = CS.CDSERVFILI         ) AND
               (ST.CDTIPOCARD   = PA.CDTCACONSFIX       ) AND
               (PA.CDFILIAL     = ST.CDFILCENTPME       ) AND
               (TC.CDFILCENTPME = ST.CDFILCENTPME       ) AND
               (TC.CDTIPOCARD   = ST.CDTIPOCARD         ) AND
               (TC.CDFILIAL     = CS.CDFILIAL           ) AND
               (TC.IDTCARATFILI = 'S'                   ) AND
               NOT EXISTS (SELECT
                              CDFILIAL
                           FROM
                              DIASEMCONSPME
                           WHERE
                              CDFILCENTPME = @P_CDFILCENTPME        AND
                              CDSERVFILI   = @V_CONSPLAN_CDSERVFILI AND
                              CDFILIAL     = @V_CONSPLAN_CDFILIAL   AND
                              DTSEMCONSPME = @V_CONSPLAN_DTDATA     AND
                              IDTPCONSPME IN (@w_F, @w_A))
            UNION ALL
            SELECT
               CS.CDFILCENTPME, CS.CDSERVFILI, CS.CDFILIAL,
               CS.DTCONSERVPME, CS.CDPRODUTO,  CS.QTCONSERVPME, CS.IDQTDECONPME
            FROM
               CONSSERVPME CS, PRODUTO, SERVTIPOCARD ST, PARAMPLANEJA PA, FILITIPOCARD TC
            WHERE
               (CS.CDFILCENTPME = @P_CDFILCENTPME       ) AND
               (CS.CDSERVFILI   = @V_CONSPLAN_CDSERVFILI) AND
               (CS.CDFILIAL     = @V_CONSPLAN_CDFILIAL  ) AND
               (CS.DTCONSERVPME = @V_CONSPLAN_DTDATA    ) AND
               (CS.IDTIPOCONPME = @w_9                  ) AND
               (CS.IDQTDECONPME = @w_P                  ) AND
               (CS.CDPRODUTO    = PRODUTO.CDPRODUTO     ) AND
               (CDARVPROD BETWEEN @P_CDPRODUTOINI AND @P_CDPRODUTOFIN) AND
               (ST.CDFILCENTPME = CS.CDFILCENTPME       ) AND
               (ST.CDSERVFILI   = CS.CDSERVFILI         ) AND
               (ST.CDTIPOCARD   = PA.CDTCACONSPER       ) AND
               (PA.CDFILIAL     = ST.CDFILCENTPME       ) AND
               (TC.CDFILCENTPME = ST.CDFILCENTPME       ) AND
               (TC.CDTIPOCARD   = ST.CDTIPOCARD         ) AND
               (TC.CDFILIAL     = CS.CDFILIAL           ) AND
               (TC.IDTCARATFILI = 'S'                   ) AND
               NOT EXISTS (SELECT
                              CDFILIAL
                           FROM
                              DIASEMCONSPME
                           WHERE
                              CDFILCENTPME = @P_CDFILCENTPME        AND
                              CDSERVFILI   = @V_CONSPLAN_CDSERVFILI AND
                              CDFILIAL     = @V_CONSPLAN_CDFILIAL   AND
                              DTSEMCONSPME = @V_CONSPLAN_DTDATA     AND
                              IDTPCONSPME IN (@w_P, @w_A))
            UNION ALL
            SELECT
               CS.CDFILCENTPME, CS.CDSERVFILI, CS.CDFILIAL,
               CS.DTCONSERVPME, CS.CDPRODUTO,  CS.QTCONSERVPME, CS.IDQTDECONPME
            FROM
               CONSSERVPME CS, PRODUTO, SERVTIPOCARD ST, PARAMPLANEJA PA, FILITIPOCARD TC
            WHERE
               (CS.CDFILCENTPME = @P_CDFILCENTPME       ) AND
               (CS.CDSERVFILI   = @V_CONSPLAN_CDSERVFILI) AND
               (CS.CDFILIAL     = @V_CONSPLAN_CDFILIAL  ) AND
               (CS.CDPRODUTO    = PRODUTO.CDPRODUTO     ) AND
               (CDARVPROD BETWEEN @P_CDPRODUTOINI AND @P_CDPRODUTOFIN) AND
               (ST.CDFILCENTPME = CS.CDFILCENTPME       ) AND
               (ST.CDSERVFILI   = CS.CDSERVFILI         ) AND
               (ST.CDTIPOCARD   = PA.CDTCACONSFIX       ) AND
               (PA.CDFILIAL     = ST.CDFILCENTPME       ) AND
               (TC.CDFILCENTPME = ST.CDFILCENTPME       ) AND
               (TC.CDTIPOCARD   = ST.CDTIPOCARD         ) AND
               (TC.CDFILIAL     = CS.CDFILIAL           ) AND
               (TC.IDTCARATFILI = 'S'                   ) AND
               DTCONSERVPME IN (SELECT MAX(DTCONSERVPME)
                                FROM CONSSERVPME
                                WHERE CDFILCENTPME =  @P_CDFILCENTPME        AND
                                      CDSERVFILI   =  @V_CONSPLAN_CDSERVFILI AND
                                      CDFILIAL     =  @V_CONSPLAN_CDFILIAL   AND
                                      DTCONSERVPME <= @V_CONSPLAN_DTDATA     AND
                                      IDTIPOCONPME <> @w_9) AND
               ((IDTIPOCONPME = DATEPART(W, @V_CONSPLAN_DTDATA) AND @V_FERIADO = @w_ZERO) OR
                (IDTIPOCONPME = @w_8 AND @V_FERIADO <> @w_ZERO)) AND
               IDQTDECONPME   = @w_F                      AND
               NOT EXISTS (SELECT
                              CDFILIAL
                           FROM
                              DIASEMCONSPME
                           WHERE
                              CDFILCENTPME = @P_CDFILCENTPME        AND
                              CDSERVFILI   = @V_CONSPLAN_CDSERVFILI AND
                              CDFILIAL     = @V_CONSPLAN_CDFILIAL   AND
                              DTSEMCONSPME = @V_CONSPLAN_DTDATA     AND
                              IDTPCONSPME IN (@w_F, @w_A))          AND
              NOT EXISTS (SELECT
                             CDFILIAL
                          FROM
                             CONSSERVPME
                          WHERE
                             CDFILCENTPME = @P_CDFILCENTPME        AND
                             CDSERVFILI   = @V_CONSPLAN_CDSERVFILI AND
                             CDFILIAL     = @V_CONSPLAN_CDFILIAL   AND
                             DTCONSERVPME = @V_CONSPLAN_DTDATA     AND
                             IDTIPOCONPME = @w_9                   AND
                             IDQTDECONPME = @w_F)
            UNION ALL
            SELECT
               CS.CDFILCENTPME,
               CS.CDSERVFILI,
               CS.CDFILIAL,
               CS.DTCONSERVPME,
               CS.CDPRODUTO,
               CS.QTCONSERVPME,
               CS.IDQTDECONPME
            FROM
               CONSSERVPME CS, PRODUTO, SERVTIPOCARD ST, PARAMPLANEJA PA, FILITIPOCARD TC
            WHERE
               (CS.CDFILCENTPME = @P_CDFILCENTPME       ) AND
               (CS.CDSERVFILI   = @V_CONSPLAN_CDSERVFILI) AND
               (CS.CDFILIAL     = @V_CONSPLAN_CDFILIAL  ) AND
               (CS.CDPRODUTO    = PRODUTO.CDPRODUTO     ) AND
               (CDARVPROD BETWEEN @P_CDPRODUTOINI AND @P_CDPRODUTOFIN) AND
               (ST.CDFILCENTPME = CS.CDFILCENTPME       ) AND
               (ST.CDSERVFILI   = CS.CDSERVFILI         ) AND
               (ST.CDTIPOCARD   = PA.CDTCACONSPER       ) AND
               (PA.CDFILIAL     = ST.CDFILCENTPME       ) AND
               (TC.CDFILCENTPME = ST.CDFILCENTPME       ) AND
               (TC.CDTIPOCARD   = ST.CDTIPOCARD         ) AND
               (TC.CDFILIAL     = CS.CDFILIAL           ) AND
               (TC.IDTCARATFILI = 'S'                   ) AND
               DTCONSERVPME IN (SELECT MAX(DTCONSERVPME)
                                FROM CONSSERVPME
                                WHERE CDFILCENTPME  = @P_CDFILCENTPME        AND
                                      CDSERVFILI    = @V_CONSPLAN_CDSERVFILI AND
                                      CDFILIAL      = @V_CONSPLAN_CDFILIAL   AND
                                      DTCONSERVPME <= @V_CONSPLAN_DTDATA     AND
                                      IDTIPOCONPME <> @w_9) AND
               ((IDTIPOCONPME = DATEPART(W, @V_CONSPLAN_DTDATA) AND @V_FERIADO = @w_ZERO) OR
                (IDTIPOCONPME = @w_8 AND @V_FERIADO <> @w_ZERO)) AND
               IDQTDECONPME   = @w_P                      AND
               NOT EXISTS (SELECT
                              CDFILIAL
                           FROM
                              DIASEMCONSPME
                           WHERE
                              CDFILCENTPME = @P_CDFILCENTPME        AND
                              CDSERVFILI   = @V_CONSPLAN_CDSERVFILI AND
                              CDFILIAL     = @V_CONSPLAN_CDFILIAL   AND
                              DTSEMCONSPME = @V_CONSPLAN_DTDATA     AND
                              IDTPCONSPME IN (@w_P, @w_A))          AND
               NOT EXISTS (SELECT
                              CDFILIAL
                           FROM
                              CONSSERVPME
                           WHERE
                              CDFILCENTPME = @P_CDFILCENTPME        AND
                              CDSERVFILI   = @V_CONSPLAN_CDSERVFILI AND
                              CDFILIAL     = @V_CONSPLAN_CDFILIAL   AND
                              DTCONSERVPME = @V_CONSPLAN_DTDATA     AND
                              IDTIPOCONPME = @w_9                   AND
                              IDQTDECONPME = @w_P)
               ORDER BY 6, 4;

         OPEN CUR_CONSSERVPME;
         FETCH NEXT FROM CUR_CONSSERVPME INTO @V_CONSSERVPME_CDFILCENTPME,
                                              @V_CONSSERVPME_CDSERVFILI,
                                              @V_CONSSERVPME_CDFILIAL,
                                              @V_CONSSERVPME_DTCONSERVPME,
                                              @V_CONSSERVPME_CDPRODUTO,
                                              @V_CONSSERVPME_QTCONSERVPME,
                                              @V_CONSSERVPME_IDQTDECONPME;

         WHILE (@@FETCH_STATUS = 0) BEGIN
            IF ((@V_IDCONSFIXO = 'F') AND (@V_CONSSERVPME_IDQTDECONPME = 'F')) OR
               ((@V_IDCONSPERC = 'P') AND (NOT @V_CONSPLAN_NRCARDAPIO IS NULL)) BEGIN

               SELECT @V_IDPRODNAREQPREV = IDPRODNAREQPREV
                 FROM PRODFILI
                WHERE CDFILIAL = @V_CONSPLAN_CDFILIAL
                  AND CDPRODUTO = @V_CONSSERVPME_CDPRODUTO;

               IF (@V_IDPRODNAREQPREV = 'S') BEGIN
                  SET @V_PERCACRES = 0;
               END ELSE BEGIN
                  SET @V_PERCACRES = @P_PEACRESCIMO;
               END;


               IF @V_CONSSERVPME_IDQTDECONPME = 'F' BEGIN
                  SET @V_QTCOMESTICAR = (@V_CONSSERVPME_QTCONSERVPME) * (1 + (@V_PERCACRES / 100));
               END
               ELSE BEGIN
                  SET @V_QTCOMESTICAR = (@V_CONSSERVPME_QTCONSERVPME * @V_CONSPLAN_QTCOMESTICAR) * (1 + (@V_PERCACRES / 100));
               END;

               IF (@V_IDCONSFIXO = 'F' AND @V_CONSSERVPME_IDQTDECONPME = 'F') OR
                  (@V_IDCONSPERC = 'P' AND @V_CONSSERVPME_IDQTDECONPME = 'P') BEGIN
                  IF @P_IDARQUIVO <> 'P' BEGIN
                     SET @V_CDFAPRATCPLA = ' ';
                     IF @V_CONSSERVPME_IDQTDECONPME = 'F' BEGIN
                        SET @V_CDTPPRATCPLA = 'FF';
                     END
                     ELSE BEGIN
                        SET @V_CDTPPRATCPLA = 'PP';
                     END;

                     SET @V_CDSETOCONSPL = '  ';

                     IF @V_CONSSERVPME_IDQTDECONPME = 'F' BEGIN
                        SET @V_CDPRATCONSPL = 'FFFFFFFFFF';
                     END
                     ELSE BEGIN
                        SET @V_CDPRATCONSPL = 'PPPPPPPPPP';
                     END;
                     SET @V_CDPRATCONSPL = '          ';
                     SET @V_CDSETOCONSPL = '  ';

                     IF @V_CONSSERVPME_IDQTDECONPME = 'F' BEGIN
                        SET @V_TPCARDCONSFIX = @V_CDTCACONSFIX;
                     END
                     ELSE BEGIN
                        SET @V_TPCARDCONSFIX = @V_CDTCACONSPER;
                     END;

                     EXEC ATUALIZA_CONSPLAN_PME
                                            @P_NRCONSPLAN,
                                            @P_CDFILCENTPME,
                                            @V_CONSPLAN_CDFILIAL,
                                            @V_TPCARDCONSFIX,
                                            @V_CONSPLAN_CDSERVFILI,
                                            @V_CONSSERVPME_IDQTDECONPME,
                                            @V_CDFAPRATCPLA,
                                            @V_CDPRATCONSPL,
                                            @V_REC_CDAPRERECE,
                                            @V_CDSETOCONSPL,
                                            @V_CONSSERVPME_CDPRODUTO,
                                            @V_CONSPLAN_DTDATA,
                                            @V_CONSPLAN_HRINICATEN,
                                            @V_CDTPPRATCPLA,
                                            @V_QTCOMESTICAR,
                                            100,
                                            @V_CONSPLAN_QTCOMESTICAR,
                                            'N',
                                            @V_CONSPLAN_DTDATA;
                  END;
               END;
            END;
            FETCH NEXT FROM CUR_CONSSERVPME INTO @V_CONSSERVPME_CDFILCENTPME,
                                                 @V_CONSSERVPME_CDSERVFILI,
                                                 @V_CONSSERVPME_CDFILIAL,
                                                 @V_CONSSERVPME_DTCONSERVPME,
                                                 @V_CONSSERVPME_CDPRODUTO,
                                                 @V_CONSSERVPME_QTCONSERVPME,
                                                 @V_CONSSERVPME_IDQTDECONPME;
         END;
         CLOSE CUR_CONSSERVPME;
         DEALLOCATE CUR_CONSSERVPME;

         FETCH NEXT FROM C_CONSPLAN INTO @V_CONSPLAN_DTDATA,
                                         @V_CONSPLAN_CDSERVFILI,
                                         @V_CONSPLAN_HRINICATEN,
                                         @V_CONSPLAN_NRCARDAPIO,
                                         @V_CONSPLAN_CDCLIENTE,
                                         @V_CONSPLAN_CDDESTFILI,
                                         @V_CONSPLAN_QTCOMESTICAR,
                                         @V_CONSPLAN_CDFILIAL;
      END;
      CLOSE C_CONSPLAN;
      DEALLOCATE C_CONSPLAN;
   END;
   /* FIM DO CONSUMO POR SERVICO */

   IF (@P_IDARREDOND = 'S') OR (@P_IDARREDOND = 'C') BEGIN
      IF @P_IDARQUIVO = 'P' BEGIN
         DECLARE CUR_ARREDOND CURSOR FOR
         SELECT
            PV.NRREQUEXTR,
            PV.CDFILIAL,
            PV.CDSERVFILI,
            PV.DTPREVRETI,
            PV.IDPREVRETI,
            NULL,
            NULL,
            PV.CDPRODUTO,
            PV.DTLIMITERETI,
            PV.HRLIMITERETI,
            NULL,
            'XXX' CDCLIENTE,
            'XXX' CDDESTFILI,
            PR.VRARREDREQ,
            PR.VRARREDCMP,
            PV.QTPREVRETI,
            PV.QTPRERETT1,
            PV.QTPRERETT2,
            PV.QTPRERETT3,
            PV.QTPRERETT4
         FROM
            CONSPLANSE CO, PRODUTO PR, PREVRETI PV
         WHERE
            (CO.CDFILICPLASE = @V_REC_CDFILIAL) AND
            (CO.NRCONSPLANSE = @P_NRCONSPLAN  ) AND
            (PV.CDFILIAL     = CO.CDFILICPLASE) AND
            (PV.CDSERVFILI   = CO.CDSERVCPLASE) AND
            (PV.NRREQUEXTR   = '0000000000'   ) AND
            (PR.CDPRODUTO    = PV.CDPRODUTO   ) AND
            (PV.DTPREVRETI BETWEEN CO.DTINICCPLASE AND CO.DTFINACPLASE);

      END
      ELSE BEGIN  /* - Consumo planejdo (CONSPLAN) para a data e servio - */
         DECLARE CUR_ARREDOND CURSOR FOR
         SELECT
            CP.NRCONSPLAN,
            CP.CDFILICPLA,
            CP.CDSERVCPLA,
            CP.DTCONSPLAN,
            CP.IDCONSPLAN,
            CP.CDFAPRATCPLA,
            CP.CDPRATCONSPL,
            CP.CDPRODCPLA,
            CP.DTLIMITECPLA,
            CP.HRLIMITECPLA,
            CP.CDTPPRATCPLA,
            CP.CDCLIECPLA,
            CP.CDDESTFICPLA,
            PR.VRARREDREQ,
            PR.VRARREDCMP,
            SUM(CP.QTCONSPLAN) QTCONSPLAN,
            SUM(CP.QTCONSPLANT1) QTCONSPLANT1,
            SUM(CP.QTCONSPLANT2) QTCONSPLANT2,
            SUM(CP.QTCONSPLANT3) QTCONSPLANT3,
            SUM(CP.QTCONSPLANT4) QTCONSPLANT4
         FROM
            PRODUTO PR, CONSPLAN CP, CONSPLANSE CO
         WHERE
            (CO.CDFILICPLASE = @V_REC_CDFILIAL) AND
            (CO.NRCONSPLANSE = @P_NRCONSPLAN) AND
            (CP.NRCONSPLAN = @P_NRCONSPLAN  ) AND
            (CP.CDFILICPLA = CO.CDFILICPLASE) AND
            (CP.CDSERVCPLA = CO.CDSERVCPLASE) AND
            (PR.CDPRODUTO  = CP.CDPRODCPLA  ) AND
            (CP.DTCONSPLAN BETWEEN CO.DTINICCPLASE AND CO.DTFINACPLASE)
         GROUP BY
            CP.NRCONSPLAN,
            CP.CDFILICPLA,
            CP.CDSERVCPLA,
            CP.DTCONSPLAN,
            CP.IDCONSPLAN,
            CP.CDCLIECPLA,
            CP.CDDESTFICPLA,
            CP.CDFAPRATCPLA,
            CP.CDPRATCONSPL,
            CP.CDPRODCPLA,
            CP.DTLIMITECPLA,
            CP.HRLIMITECPLA,
            CP.CDTPPRATCPLA,
            PR.VRARREDREQ,
            PR.VRARREDCMP;
      END;
      OPEN CUR_ARREDOND;

      FETCH NEXT FROM CUR_ARREDOND INTO @V_REC_ARR_NRCONSPLAN,
                                        @V_REC_ARR_CDFILICPLA,
                                        @V_REC_ARR_CDSERVCPLA,
                                        @V_REC_ARR_DTCONSPLAN,
                                        @V_REC_ARR_IDCONSPLAN,
                                        @V_REC_ARR_CDFAPRATCPLA,
                                        @V_REC_ARR_CDPRATCONSPL,
                                        @V_REC_ARR_CDPRODCPLA,
                                        @V_REC_ARR_DTLIMITECPLA,
                                        @V_REC_ARR_HRLIMITECPLA,
                                        @V_REC_ARR_CDTPPRATCPLA,
                                        @V_REC_ARR_CDCLIECPLA,
                                        @V_REC_ARR_CDDESTFICPLA,
                                        @V_REC_ARR_VRARREDREQ,
                                        @V_REC_ARR_VRARREDCMP,
                                        @V_REC_ARR_QTCONSPLAN,
                                        @V_REC_ARR_QTCONSPLANT1,
                                        @V_REC_ARR_QTCONSPLANT2,
                                        @V_REC_ARR_QTCONSPLANT3,
                                        @V_REC_ARR_QTCONSPLANT4;


      WHILE (@@FETCH_STATUS = 0) BEGIN
         IF (@P_IDARREDOND = 'S') BEGIN
            SET @V_ARRED = @V_REC_ARR_VRARREDREQ;
         END
         ELSE BEGIN
            SET @V_ARRED = @V_REC_ARR_VRARREDCMP;
         END;

         IF NOT (@V_ARRED IS NULL) AND (@V_ARRED <> 0) BEGIN
            IF (@V_REC_ARR_QTCONSPLANT1 > 0) AND ((@V_REC_ARR_QTCONSPLANT1 - @V_ARRED*FLOOR(@V_REC_ARR_QTCONSPLANT1/@V_ARRED)) > 0) BEGIN
               SET @V_QTPREV1 = (FLOOR(@V_REC_ARR_QTCONSPLANT1/@V_ARRED) + 1) * @V_ARRED;
            END
            ELSE BEGIN
               SET @V_QTPREV1 = @V_REC_ARR_QTCONSPLANT1;
            END;

            IF (@V_REC_ARR_QTCONSPLANT2 > 0) AND ((@V_REC_ARR_QTCONSPLANT2 - @V_ARRED*FLOOR(@V_REC_ARR_QTCONSPLANT2/@V_ARRED)) > 0) BEGIN
               SET @V_QTPREV2 = (FLOOR(@V_REC_ARR_QTCONSPLANT2/@V_ARRED) + 1) * @V_ARRED;
            END
            ELSE BEGIN
               SET @V_QTPREV2 = @V_REC_ARR_QTCONSPLANT2;
            END;

            IF (@V_REC_ARR_QTCONSPLANT3 > 0) AND ((@V_REC_ARR_QTCONSPLANT3 - @V_ARRED*FLOOR(@V_REC_ARR_QTCONSPLANT3/@V_ARRED)) > 0) BEGIN
               SET @V_QTPREV3 = (FLOOR(@V_REC_ARR_QTCONSPLANT3/@V_ARRED) + 1) * @V_ARRED;
            END
            ELSE BEGIN
               SET @V_QTPREV3 = @V_REC_ARR_QTCONSPLANT3;
            END;

            IF (@V_REC_ARR_QTCONSPLANT4 > 0) AND ((@V_REC_ARR_QTCONSPLANT4 - @V_ARRED*FLOOR(@V_REC_ARR_QTCONSPLANT4/@V_ARRED)) > 0) BEGIN
               SET @V_QTPREV4 = (FLOOR(@V_REC_ARR_QTCONSPLANT4/@V_ARRED) + 1) * @V_ARRED;
            END
            ELSE BEGIN
               SET @V_QTPREV4 = @V_REC_ARR_QTCONSPLANT4;
            END;

            IF (@V_QTPREV1 = 0) AND (@V_QTPREV2 = 0) AND (@V_QTPREV3 = 0) AND (@V_QTPREV4 = 0) BEGIN
               IF (@V_REC_ARR_QTCONSPLAN > 0) AND ((@V_REC_ARR_QTCONSPLAN - @V_ARRED*FLOOR(@V_REC_ARR_QTCONSPLAN/@V_ARRED)) >= 0) BEGIN
                  SET @V_QTPREV = (FLOOR(@V_REC_ARR_QTCONSPLAN/@V_ARRED) + 1) * @V_ARRED;
               END
               ELSE BEGIN
                  SET @V_QTPREV = @V_REC_ARR_QTCONSPLAN;
               END;
            END
            ELSE BEGIN
               SET @V_QTPREV = @V_QTPREV1 + @V_QTPREV2 + @V_QTPREV3 + @V_QTPREV4;
            END;

            UPDATE
               CONSPLAN
            SET
               QTCONSPLAN   = @V_QTPREV,
               QTCONSPLANT1 = @V_QTPREV1,
               QTCONSPLANT2 = @V_QTPREV2,
               QTCONSPLANT3 = @V_QTPREV3,
               QTCONSPLANT4 = @V_QTPREV4,
               QTCONSPLANSA = @V_REC_ARR_QTCONSPLAN,
               QTCONPLAT1SA = @V_REC_ARR_QTCONSPLANT1,
               QTCONPLAT2SA = @V_REC_ARR_QTCONSPLANT2,
               QTCONPLAT3SA = @V_REC_ARR_QTCONSPLANT3,
               QTCONPLAT4SA = @V_REC_ARR_QTCONSPLANT4
            WHERE
               (CDFILICPLA   = @V_REC_ARR_CDFILICPLA  ) AND
               (NRCONSPLAN   = @V_REC_ARR_NRCONSPLAN  ) AND
               (CDSERVCPLA   = @V_REC_ARR_CDSERVCPLA  ) AND
               (DTCONSPLAN   = @V_REC_ARR_DTCONSPLAN  ) AND
               (IDCONSPLAN   = @V_REC_ARR_IDCONSPLAN  ) AND
               (CDCLIECPLA   = @V_REC_ARR_CDCLIECPLA  ) AND
               (CDDESTFICPLA = @V_REC_ARR_CDDESTFICPLA) AND
               (CDFAPRATCPLA = @V_REC_ARR_CDFAPRATCPLA) AND
               (CDPRATCONSPL = @V_REC_ARR_CDPRATCONSPL) AND
               (CDPRODCPLA   = @V_REC_ARR_CDPRODCPLA  ) AND
               (DTLIMITECPLA = @V_REC_ARR_DTLIMITECPLA) AND
               (HRLIMITECPLA = @V_REC_ARR_HRLIMITECPLA) AND
               (CDTPPRATCPLA = @V_REC_ARR_CDTPPRATCPLA);
         END;
         FETCH NEXT FROM CUR_ARREDOND INTO @V_REC_ARR_NRCONSPLAN,
                                           @V_REC_ARR_CDFILICPLA,
                                           @V_REC_ARR_CDSERVCPLA,
                                           @V_REC_ARR_DTCONSPLAN,
                                           @V_REC_ARR_IDCONSPLAN,
                                           @V_REC_ARR_CDFAPRATCPLA,
                                           @V_REC_ARR_CDPRATCONSPL,
                                           @V_REC_ARR_CDPRODCPLA,
                                           @V_REC_ARR_DTLIMITECPLA,
                                           @V_REC_ARR_HRLIMITECPLA,
                                           @V_REC_ARR_CDTPPRATCPLA,
                                           @V_REC_ARR_CDCLIECPLA,
                                           @V_REC_ARR_CDDESTFICPLA,
                                           @V_REC_ARR_VRARREDREQ,
                                           @V_REC_ARR_VRARREDCMP,
                                           @V_REC_ARR_QTCONSPLAN,
                                           @V_REC_ARR_QTCONSPLANT1,
                                           @V_REC_ARR_QTCONSPLANT2,
                                           @V_REC_ARR_QTCONSPLANT3,
                                           @V_REC_ARR_QTCONSPLANT4;
      END;
      CLOSE CUR_ARREDOND;
      DEALLOCATE CUR_ARREDOND;
   END; /* ARREDONDAMENTO DE REQUISICAO */
END;

-- VERSAO --
EXEC ATUVEROBJ 'CONSUMO_PLANEJADO_PME','5.07.005';
GO

