import {
  Loader, Metadata, Config, IEventParam, IDictionary,
} from '@zeedhi/core';
import {
  Form, CheckboxMultiple, Button, Radio,
} from '@zeedhi/common';
import { PmeMask } from '@/config';

export class Pme03100EmissaoCardDiaController {
  public reportController = Loader.getInstance('ReportController');

  public appController = Loader.getInstance('AppController');

  public utilities = Loader.getInstance('Utilities');
  
  private relatoriosEmissaoCardapio = Loader.getInstance('RelatoriosEmissaoCardController');
  
  private elaboracaoCardapio = Loader.getInstance('Pme00600ElaboracaoCardapio');

  private impConfig = {
    IMPNDPCAL: 'N',
    IMPNUTR: 'N',
    IMPMSG: 'N',
  };

  public generateReport({ component }: IEventParam<Button>) {
    const form = Metadata.getInstance<Form>('FORMEMISSAOCARDDIA');
    if (this.utilities.centralIsValid() && this.formIsValid(form)) {
      const row: IDictionary = form.value;
      
      this.setParams(row);
      if (!row.CDFILCENTPME) this.utilities.showAlert('alertError', 'pme::centralNaoInformada', 'error');
      else {
        this.reportController.callGenerateReport(component, row, 'report/emissaoCardDia');
      }
    }
  }
  
  private setParams(row: IDictionary) {
    const mask: string = (Config.masks.productMask as PmeMask).pattern;
    const paramsCard = this.relatoriosEmissaoCardapio.getParamsCard();
    
    row.NRCARDPME = paramsCard?.NRCARDPME ?? this.elaboracaoCardapio.getFilterData.NRCARDPME;
    row.IMPNDPCAL = this.impConfig.IMPNDPCAL;
    row.IMPNUTR = this.impConfig.IMPNUTR;
    row.IMPMSG = this.impConfig.IMPMSG;
    row.NMFILIAGRE = row.UNIDADE ? row.UNIDADE.NMFILIAL : null;
    row.CDFILIAL = row.UNIDADE ? row.UNIDADE.CDFILIAL : null;
    row.CDSERVFILI = row.SERVICO ? row.SERVICO : null;
    row.CDFILCENTPME = this.appController.getCdCentral();
    row.NMFILCENTPME = this.appController.getNmCentral();
    row.REPORT_NAME = row.REPORT.REPORT_NAME;
    row.CD_REPORT_CODE = row.REPORT.CD_REPORT_CODE;
    row.PRODUCTMASK = this.utilities.formatReportMask(mask);
  }

  private formIsValid(form: Form) {
    let valid = false;
    const row: IDictionary = form.value;
    const periodoDe = row.PERIODODE;
    const periodoAte = row.PERIODOATE;
    // form.validate();
    if (form.validate()) {
      const dtDe = row.DTDE;
      const dtAte = row.DTATE;

      if (this.utilities.dateIsValid(periodoDe, periodoAte) && this.utilities.dateIsValid(dtDe, dtAte)) {
        if (this.utilities.dateIsValid(periodoDe, dtDe) && this.utilities.dateIsValid(dtAte, periodoAte)) valid = true;
        else this.utilities.showAlert('alertError', 'pme::dtCompreendidaPerCard', 'error');
      } else this.utilities.showAlert('alertError', 'pme::dataIniMaior', 'error');
    }
    return valid;
  }

  public setImpConfig({ component }: IEventParam<CheckboxMultiple>) {
    if (component.value) {
      const items = Array.isArray(component.value) ? component.value.join('_') : component.value;
      const consPrat = Metadata.getInstance<CheckboxMultiple>('CONSPRAT');
      const quebra = Metadata.getInstance<CheckboxMultiple>('QUEBRA');

      if (items.includes('IMPNDPCAL')) this.impConfig.IMPNDPCAL = 'S';
      else this.impConfig.IMPNDPCAL = 'N';

      if (items.includes('IMPNUTR')) {
        this.impConfig.IMPNUTR = 'S';
        consPrat.disabled = false;
      } else {
        this.impConfig.IMPNUTR = 'N';
        consPrat.disabled = true;
      }

      if (items.includes('IMPMSG')) {
        quebra.disabled = true;
        this.impConfig.IMPMSG = 'S';
      } else {
        quebra.disabled = false;
        this.impConfig.IMPMSG = 'N';
      }
    }
  }

  public defaultImpComen({ component }: IEventParam<Radio>) {
    const central = this.appController.getCdCentral();
    if (central) {
      this.utilities.getParamPlaneja(central).then((paramplaneja: IDictionary) => {
        const idperccome = paramplaneja?.IDPERCCOME;
        if (idperccome === 'C') component.value = '0';
        else component.value = '1';
      });
    }
  }
}
